ECHO OFF
REM     ------------------------------------------------------------------------
REM     WinMoDo2.bat
REM
REM     Converts source .LZH, .BIN, .MOT, .SRE, .ABS files
REM     to .REL files, suitable for the WinGD70 downloader.
REM
REM
REM     %1  = Path of source file, terminated by '\'
REM     %2  = Filename stem (name without extension) of source file
REM     %3  = File extension of source file (including the '.')
REM     %4  = Path of destination file, terminated by '\'
REM     %5  = Filename stem of destination file
REM     %6  = Product ID
REM     %7  = HEX470 Command File
REM     %8  = LP file size
REM     ------------------------------------------------------------------------


REM     ------------------------------------------------------------------------
REM     Process according to source extension
REM     ------------------------------------------------------------------------
		IF "%3"==".lzh" GOTO LZH
		IF "%3"==".bin" GOTO BIN
		IF "%3"==".mot" GOTO SRE
		IF "%3"==".sre" GOTO SRE
		IF "%3"==".abs" GOTO ABS
ECHO UNRECOGNISED SOURCE FILE EXTENSION "%3"
PAUSE
		GOTO EXIT





REM     ------------------------------------------------------------------------
REM     Compressed file - Decompress to destination drive
REM     Process according to what gets written
REM     ------------------------------------------------------------------------
:LZH
		LHA E %1%2%3 %4
		IF EXIST %4%5.bin GOTO BIN2
		IF EXIST %4%5.mot GOTO MOT2
		IF EXIST %4%5.sre GOTO SRE2
		IF EXIST %4%5.abs GOTO ABS2
		IF EXIST %4%5     GOTO BIN3
		IF EXIST %4%5.rel GOTO EXIT
ECHO FAILED TO EXTRACT %4%5.;.bin;.mot;.sre;.abs;.rel from %1%2%3
PAUSE
		GOTO EXIT





REM     ------------------------------------------------------------------------
REM     Binary file - convert to release on dest drive, renaming as we go
REM     ------------------------------------------------------------------------
:BIN
		IF EXIST %4%5.rel DEL %4%5.rel
		BIN2REL %1%2.bin %4%5.rel %6
		IF NOT EXIST %4%5.rel GOTO ERROR
		GOTO EXIT





REM     ------------------------------------------------------------------------
REM     S-Record - convert to .bin file on dest drive and rename
REM     Convert .bin file to release file
REM     ------------------------------------------------------------------------
:SRE
		IF EXIST %4%5.bin DEL %4%5.bin
                IF "%8"=="" GOTO NOLPSRE
                MOT2BIN %1%2%3  %4%5.bin %8 LP
                GOTO LPSRE
:NOLPSRE		
                MOT2BIN %1%2%3  %4%5.bin 2048  
:LPSRE
                IF NOT EXIST %4%5.bin GOTO ERROR
		IF EXIST %4%5.rel DEL %4%5.rel
		BIN2REL %4%5.bin %4%5.rel %6
		DEL %4%5.bin
		IF NOT EXIST %4%5.rel GOTO ERROR
		GOTO EXIT





REM     ------------------------------------------------------------------------
REM     ABS file - convert to .mot file in destination drive, renaming as we go
REM     Convert .mot file to .bin then to .rel file
REM     ------------------------------------------------------------------------
:ABS
		IF EXIST %4%5.mot DEL %4%5.mot
ECHO CONVERTING %1%2%3 to %4%5.mot
		HEX470 %1%2%3 -q -o %4%5.mot %7
		IF NOT EXIST %4%5.MOT GOTO ERROR
		IF EXIST %4%5.bin DEL %4%5.bin
ECHO CONVERTING %4%5.mot to %4%5.bin
                IF "%8"=="" GOTO NOLPABS
       		MOT2BIN %4%5.mot %4%5.bin %8 LP
                GOTO LPABS
:NOLPABS
                MOT2BIN %4%5.mot %4%5.bin 2048
:LPABS                
		DEL %4%5.mot
		IF NOT EXIST %4%5.bin GOTO ERROR
		IF EXIST %4%5.rel DEL %4%5.rel
ECHO CONVERTING %4%5.bin TO %6 RELEASE FILE %4%5.rel
		BIN2REL %4%5.bin %4%5.rel %6
		DEL %4%5.bin
		IF NOT EXIST %4%5.rel GOTO ERROR
		GOTO EXIT





REM     ------------------------------------------------------------------------
REM     Decompressed .bin file on destination drive - convert to release file
REM     ------------------------------------------------------------------------
:BIN2
		IF EXIST %4%5.rel DEL %4%5.rel
		BIN2REL %4%5.bin %4%5.rel %6
		DEL %4%5.bin
		IF NOT EXIST %4%5.rel GOTO ERROR
		GOTO EXIT





REM     ------------------------------------------------------------------------
REM     Decompressed (bin) file on destination drive - convert to release file
REM     ------------------------------------------------------------------------
:BIN3
		IF EXIST %4%5.rel DEL %4%5.rel
		BIN2REL %4%5 %4%5.rel %6
		DEL %4%5
		IF NOT EXIST %4%5.rel GOTO ERROR
		GOTO EXIT





REM     ------------------------------------------------------------------------
REM     Decompressed .mot file on destination drive. Convert to .bin, then .rel
REM     ------------------------------------------------------------------------
:MOT2
		IF EXIST %4%5.bin DEL %4%5.bin
                IF "%8"=="" GOTO NOLPMOT2
		MOT2BIN %4%2.mot %4%5.bin %8 LP
                GOTO LPMOT2
:NOLPMOT2
		MOT2BIN %4%2.mot %4%5.bin 2048
:LPMOT2
		DEL %4%2.mot
		IF NOT EXIST %4%5.bin GOTO ERROR
		IF EXIST %4%5.rel DEL %4%5.rel
		BIN2REL %4%5.bin %4%5.rel %6
		DEL %4%5.bin
		IF NOT EXIST %4%5.rel GOTO ERROR
		GOTO EXIT





REM     ------------------------------------------------------------------------
REM     Decompressed .sre file on destination drive. Convert to .bin, then .rel
REM     ------------------------------------------------------------------------
:SRE2
		IF EXIST %4%5.bin DEL %4%5.bin
                IF "%8"=="" GOTO NOLPSRE2
		MOT2BIN %4%2.sre %4%5.bin %8 LP
                GOTO LPSRE2
:NOLPSRE2
		MOT2BIN %4%2.sre %4%5.bin 2048
:LPSRE2
		DEL %4%2.sre
		IF NOT EXIST %4%5.bin GOTO ERROR
		IF EXIST %4%5.rel DEL %4%5.rel
		BIN2REL %4%5.bin %4%5.rel %6
		DEL %4%5.bin
		IF NOT EXIST %4%5.rel GOTO ERROR
		GOTO EXIT





REM     ------------------------------------------------------------------------
REM     Decompressed .abs file on destination drive.
REM     Convert to .mot, then .bin then .rel
REM     ------------------------------------------------------------------------
:ABS2
		IF EXIST %4%5.mot DEL %4%5.mot
		HEX470 %4%5.abs -q -o %4%5.mot %7
		DEL %4%5.abs
		IF NOT EXIST %4%5.mot GOTO ERROR
		IF EXIST %4%5.bin DEL %4%5.bin
                IF "%8"=="" GOTO NOLPABS2
		MOT2BIN %4%5.mot %4%5.bin %8 LP
                GOTO LPABS2
:NOLPABS2
		MOT2BIN %4%5.mot %4%5.bin 2048
:LPABS2
		DEL %4%5.mot
		IF NOT EXIST %4%5.bin GOTO ERROR
		IF EXIST %4%5.rel DEL %4%5.rel
		BIN2REL %4%5.bin %4%5.rel %6
		DEL %4%5.bin
		IF NOT EXIST %4%5.rel GOTO ERROR
		GOTO EXIT



:ERROR
ECHO Could not create %4%5.rel. Check format of %1%2%3. Check all utilities are present.
PAUSE


:EXIT


